@@ -17,11 +17,11 @@ Perl::Critic::Git - Bond git and Perl::Critic to blame the right people for viol
 
 =head1 VERSION
 
-Version 1.3.0
+Version 1.3.1
 
 =cut
 
-our $VERSION = '1.3.0';
+our $VERSION = '1.3.1';
 
 
 =head1 SYNOPSIS
@@ -33,7 +33,7 @@ our $VERSION = '1.3.0';
 	);
 
 	my $violations = $git_critic->report_violations(
-		author => $author,                 # or undef for all
+		author => $author,
 		since  => $date,                   # to critique only recent changes
 	);
 
@@ -134,7 +134,7 @@ sub get_authors
 Report the violations for a given Git author.
 
 	my $violations = $git_critic->report_violations(
-		author => $author,                 # or undef for all
+		author => $author,
 		since  => $date,                   # to critique only recent changes
 	);
 
@@ -469,7 +469,7 @@ I originally developed this project for ThinkGeek
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012-2017 Guillaume Aubert.
+Copyright 2012-2018 Guillaume Aubert.
 
 This code is free software; you can redistribute it and/or modify it under the
 same terms as Perl 5 itself.
